pub struct InMemoryVamana<T: Scalar + Send + Sync> { /* private fields */ }Implementations
Sourceimpl<T: Scalar + Send + Sync> InMemoryVamana<T>
impl<T: Scalar + Send + Sync> InMemoryVamana<T>
pub fn new( adj_list: DashMap<Id, Vec<Id>>, id_to_point: DashMap<Id, Array1<T>>, ) -> Self
Sourcepub fn graph(&self) -> &DashMap<Id, Vec<Id>>
pub fn graph(&self) -> &DashMap<Id, Vec<Id>>
This can be useful for serializing to disk. Usually the points are already stored elsewhere, so serializing the graph alone can save space. To deserialize, collect the points, deserialize this graph, and use InMemoryVamana::new. This can also be used to introspect the graph, e.g. for debugging, analysis, or research.
pub fn init_random_index( dataset: Vec<(Id, Array1<T>)>, metric: Metric<T>, params: VamanaParams, medoid_sample_size: usize, ) -> Vamana<T, Self>
pub fn build_index( dataset: Vec<(Id, Array1<T>)>, metric: Metric<T>, params: VamanaParams, medoid_sample_size: usize, ) -> Vamana<T, Self>